@@ -17,7 +17,8 @@ import logging
 from holmes.config import Config
 from holmes.facters import Facter
 from holmes.validators.base import Validator
-from holmes.models import Page
+from holmes.models import Page, Request, Domain
+from holmes.utils import get_domain_from_url
 
 
 class InvalidReviewError(RuntimeError):
@@ -125,7 +126,33 @@ class Reviewer(object):
 
     def _async_get(self, url, handler, method='GET', **kw):
         if self.async_get_func:
-            self.async_get_func(url, handler, method, **kw)
+            self.async_get_func(url, self.handle_async_get(handler), method, **kw)
+
+    def handle_async_get(self, handler):
+        def handle(url, response):
+            self.save_request(url, response)
+            handler(url, response)
+
+        return handle
+
+    def save_request(self, url, response):
+        request_time = response.request_time
+        effective_url = response.effective_url
+        status_code = response.status_code
+
+        domain_name, domain_url = get_domain_from_url(url)
+        if domain_name not in Domain.get_domain_names(self.db):
+            return
+
+        req = Request(
+            domain_name=domain_name,
+            url=url,
+            effective_url=effective_url,
+            status_code=int(status_code),
+            response_time=request_time
+        )
+
+        self.db.add(req)
 
     def review(self):
         self.load_content(self.content_loaded)
@@ -224,7 +251,7 @@ class Reviewer(object):
 
         self.wait_for_async_requests()
 
-    def handle_page_added(self, url, result, page):
+    def handle_page_added(self, (url, result, page)):
         if not result:
             error_message = "Could not enqueue page '" + url + "'! Error: %s"
             logging.error(error_message % page)
